# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'DataPartitionNamesArgs',
    'EnergyServicePropertiesArgs',
]

@pulumi.input_type
class DataPartitionNamesArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The list of Energy services resource's Data Partition Names.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class EnergyServicePropertiesArgs:
    def __init__(__self__, *,
                 auth_app_id: Optional[pulumi.Input[str]] = None,
                 data_partition_names: Optional[pulumi.Input[Sequence[pulumi.Input['DataPartitionNamesArgs']]]] = None):
        if auth_app_id is not None:
            pulumi.set(__self__, "auth_app_id", auth_app_id)
        if data_partition_names is not None:
            pulumi.set(__self__, "data_partition_names", data_partition_names)

    @property
    @pulumi.getter(name="authAppId")
    def auth_app_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auth_app_id")

    @auth_app_id.setter
    def auth_app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_app_id", value)

    @property
    @pulumi.getter(name="dataPartitionNames")
    def data_partition_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DataPartitionNamesArgs']]]]:
        return pulumi.get(self, "data_partition_names")

    @data_partition_names.setter
    def data_partition_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DataPartitionNamesArgs']]]]):
        pulumi.set(self, "data_partition_names", value)


