# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'DiskMode',
    'DiskType',
    'FirmwareType',
    'IPAddressAllocationMethod',
    'IdentityType',
    'InventoryType',
    'NICType',
    'OsType',
    'PowerOnBootOption',
    'ProvisioningAction',
]


class DiskMode(str, Enum):
    """
    Gets or sets the disk mode.
    """
    PERSISTENT = "persistent"
    INDEPENDENT_PERSISTENT = "independent_persistent"
    INDEPENDENT_NONPERSISTENT = "independent_nonpersistent"


class DiskType(str, Enum):
    """
    Gets or sets the disk backing type.
    """
    FLAT = "flat"
    PMEM = "pmem"
    RAWPHYSICAL = "rawphysical"
    RAWVIRTUAL = "rawvirtual"
    SPARSE = "sparse"
    SESPARSE = "sesparse"
    UNKNOWN = "unknown"


class FirmwareType(str, Enum):
    """
    Firmware type
    """
    BIOS = "bios"
    EFI = "efi"


class IPAddressAllocationMethod(str, Enum):
    """
    Gets or sets the nic allocation method.
    """
    UNSET = "unset"
    DYNAMIC = "dynamic"
    STATIC = "static"
    LINKLAYER = "linklayer"
    RANDOM = "random"
    OTHER = "other"


class IdentityType(str, Enum):
    """
    The type of managed service identity.
    """
    NONE = "None"
    SYSTEM_ASSIGNED = "SystemAssigned"


class InventoryType(str, Enum):
    """
    They inventory type.
    """
    RESOURCE_POOL = "ResourcePool"
    VIRTUAL_MACHINE = "VirtualMachine"
    VIRTUAL_MACHINE_TEMPLATE = "VirtualMachineTemplate"
    VIRTUAL_NETWORK = "VirtualNetwork"
    CLUSTER = "Cluster"
    DATASTORE = "Datastore"
    HOST = "Host"


class NICType(str, Enum):
    """
    NIC type
    """
    VMXNET3 = "vmxnet3"
    VMXNET2 = "vmxnet2"
    VMXNET = "vmxnet"
    E1000 = "e1000"
    E1000E = "e1000e"
    PCNET32 = "pcnet32"


class OsType(str, Enum):
    """
    Gets or sets the type of the os.
    """
    WINDOWS = "Windows"
    LINUX = "Linux"
    OTHER = "Other"


class PowerOnBootOption(str, Enum):
    """
    Gets or sets the power on boot.
    """
    ENABLED = "enabled"
    DISABLED = "disabled"


class ProvisioningAction(str, Enum):
    """
    Gets or sets the guest agent provisioning action.
    """
    INSTALL = "install"
    UNINSTALL = "uninstall"
    REPAIR = "repair"
