# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'FailoverDeploymentModel',
    'PossibleOperationsDirections',
    'RecoveryPlanGroupType',
    'ReplicationProtectedItemOperation',
    'SetMultiVmSyncStatus',
]


class FailoverDeploymentModel(str, Enum):
    """
    The failover deployment model.
    """
    NOT_APPLICABLE = "NotApplicable"
    CLASSIC = "Classic"
    RESOURCE_MANAGER = "ResourceManager"


class PossibleOperationsDirections(str, Enum):
    PRIMARY_TO_RECOVERY = "PrimaryToRecovery"
    RECOVERY_TO_PRIMARY = "RecoveryToPrimary"


class RecoveryPlanGroupType(str, Enum):
    """
    The group type.
    """
    SHUTDOWN = "Shutdown"
    BOOT = "Boot"
    FAILOVER = "Failover"


class ReplicationProtectedItemOperation(str, Enum):
    REVERSE_REPLICATE = "ReverseReplicate"
    COMMIT = "Commit"
    PLANNED_FAILOVER = "PlannedFailover"
    UNPLANNED_FAILOVER = "UnplannedFailover"
    DISABLE_PROTECTION = "DisableProtection"
    TEST_FAILOVER = "TestFailover"
    TEST_FAILOVER_CLEANUP = "TestFailoverCleanup"
    FAILBACK = "Failback"
    FINALIZE_FAILBACK = "FinalizeFailback"
    CHANGE_PIT = "ChangePit"
    REPAIR_REPLICATION = "RepairReplication"
    SWITCH_PROTECTION = "SwitchProtection"
    COMPLETE_MIGRATION = "CompleteMigration"


class SetMultiVmSyncStatus(str, Enum):
    """
    A value indicating whether multi-VM sync has to be enabled. Value should be 'Enabled' or 'Disabled'.
    """
    ENABLE = "Enable"
    DISABLE = "Disable"
