# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'EndpointType',
]


class EndpointType(str, Enum):
    """
    Type of the endpoint for the event subscription destination
    """
    WEB_HOOK = "WebHook"
    EVENT_HUB = "EventHub"
