# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'AccessRights',
    'DefaultAction',
    'EncodingCaptureDescription',
    'EntityStatus',
    'NetworkRuleIPAction',
    'SkuName',
    'SkuTier',
]


class AccessRights(str, Enum):
    MANAGE = "Manage"
    SEND = "Send"
    LISTEN = "Listen"


class DefaultAction(str, Enum):
    """
    Default Action for Network Rule Set
    """
    ALLOW = "Allow"
    DENY = "Deny"


class EncodingCaptureDescription(str, Enum):
    """
    Enumerates the possible values for the encoding format of capture description. Note: 'AvroDeflate' will be deprecated in New API Version
    """
    AVRO = "Avro"
    AVRO_DEFLATE = "AvroDeflate"


class EntityStatus(str, Enum):
    """
    Enumerates the possible values for the status of the Event Hub.
    """
    ACTIVE = "Active"
    DISABLED = "Disabled"
    RESTORING = "Restoring"
    SEND_DISABLED = "SendDisabled"
    RECEIVE_DISABLED = "ReceiveDisabled"
    CREATING = "Creating"
    DELETING = "Deleting"
    RENAMING = "Renaming"
    UNKNOWN = "Unknown"


class NetworkRuleIPAction(str, Enum):
    """
    The IP Filter Action
    """
    ALLOW = "Allow"


class SkuName(str, Enum):
    """
    Name of this SKU.
    """
    BASIC = "Basic"
    STANDARD = "Standard"


class SkuTier(str, Enum):
    """
    The billing tier of this particular SKU.
    """
    BASIC = "Basic"
    STANDARD = "Standard"
